import { LucideIcon } from "lucide-react";
import { Tabs } from "@radix-ui/react-tabs";
import { TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";

interface TabsItem {
  icon: LucideIcon;
  label: string;
  value: string;
  content: React.ReactNode;
}

interface TabsCardProps {
  tabsItems: TabsItem[];
}

export function TabsCard({ tabsItems }: TabsCardProps) {
  return (
    <Tabs
      defaultValue={tabsItems[0].value}
      className="h-full w-full flex flex-col"
    >
      <TabsList className="h-9 w-full flex flex-row items-center justify-start rounded-t-lg rounded-b-none">
        {tabsItems.map((tabsItem) => (
          <TabsTrigger
            value={tabsItem.value}
            key={tabsItem.value}
            className="gap-x-1 px-2"
          >
            <tabsItem.icon className="h-6 w-auto text-cyan-500" />
            <span>{tabsItem.label}</span>
          </TabsTrigger>
        ))}
      </TabsList>
      {tabsItems.map((tabsItem) => (
        <TabsContent value={tabsItem.value} key={tabsItem.value}>
          {tabsItem.content}
        </TabsContent>
      ))}
    </Tabs>
  );
}
